@@ -30,3 +30,15 @@ names(p) <- NULL
 
 stopifnot(all.equal(p, 1))
 
+# From Achim Zeileis <zeileis@ci.tuwien.ac.at>
+# 15.04.2002
+
+ramsay <- c(111, 107, 100, 99, 102, 106, 109, 108,
+  104, 99, 101, 96, 97, 102, 107, 113, 116, 113, 110, 98)
+jung.parekh <- c(107, 108, 106, 98, 105, 103, 110, 105,
+  104, 100, 96, 108, 103, 104, 114, 114, 113, 108, 106, 99)
+scores <- rank(c(ramsay, jung.parekh))
+scores <- pmin(scores, length(ramsay) + length(jung.parekh) - scores + 1)
+AB <- sum(scores[seq(along = ramsay)])
+pperm(AB, scores, length(ramsay), alternative = "two.sided")
+perm.test(scores[1:20], scores[21:40])
